@@ -9,17 +9,19 @@ from expressmoney.api.utils import log
 
 
 class BaseCacheMixin:
+    _cache_enabled: bool = True
     _cache_period: int = None
 
     @log
     def flush_cache(self):
         """Delete Redis cache for current endpoint"""
         self._memory_cache = None
-        cache.delete(self._get_cache_key())
+        if self._cache_enabled:
+            cache.delete(self._get_cache_key())
 
     @property
     def _cache(self):
-        if self._memory_cache is None:
+        if self._cache_enabled and self._memory_cache is None:
             try:
                 total_cache_data = cache.get(self._get_cache_key())
                 cache_data = total_cache_data.get(self._data_key) if total_cache_data else None
@@ -33,12 +35,13 @@ class BaseCacheMixin:
     @_cache.setter
     def _cache(self, value):
         if value is not None:
-            cache_data = {f'{self._data_key}': value}
-            total_cache_data = cache.get(self._get_cache_key())
-            if isinstance(total_cache_data, dict):
-                total_cache_data.update(cache_data)
-            total_cache_data = total_cache_data if total_cache_data else cache_data
-            cache.set(self._get_cache_key(), total_cache_data, self._cache_period)
+            if self._cache_enabled:
+                cache_data = {f'{self._data_key}': value}
+                total_cache_data = cache.get(self._get_cache_key())
+                if isinstance(total_cache_data, dict):
+                    total_cache_data.update(cache_data)
+                total_cache_data = total_cache_data if total_cache_data else cache_data
+                cache.set(self._get_cache_key(), total_cache_data, self._cache_period)
             self._memory_cache = value
 
     def _get_related_points(self) -> list:
