@@ -175,7 +175,7 @@ class ContractPoint(FilterMixin, CacheMixin, Point):
     _sort_by = 'id'
 
     def __init__(self,
-                 user: User,
+                 user: User = 1,
                  query_params: dict = None,
                  is_async: bool = False,
                  timeout: tuple = (30, 30),
