@@ -5,13 +5,14 @@ class AuthRouter:
     """
     AUTH_DB = 'auth_db'
     route_app_labels = {'auth', 'contenttypes', 'admin', 'authtoken'}
+    exclude_models = ('permission', 'group', 'group_permissions')
 
     def db_for_read(self, model, **_hints):
         """
         Attempts to read auth and contenttypes models go to auth_db.
         """
         model_meta = getattr(model, '_meta')
-        if model_meta.app_label in self.route_app_labels:
+        if model_meta.app_label in self.route_app_labels and model_meta.model_name not in self.exclude_models:
             return self.AUTH_DB
         return None
 
@@ -20,7 +21,7 @@ class AuthRouter:
         Attempts to write auth and contenttypes models go to auth_db.
         """
         model_meta = getattr(model, '_meta')
-        if model_meta.app_label in self.route_app_labels:
+        if model_meta.app_label in self.route_app_labels and model_meta.model_name not in self.exclude_models:
             return self.AUTH_DB
         return None
 
@@ -32,8 +33,8 @@ class AuthRouter:
         obj1_meta = getattr(obj1, '_meta')
         obj2_meta = getattr(obj2, '_meta')
         if (
-                obj1_meta.app_label in self.route_app_labels or
-                obj2_meta.app_label in self.route_app_labels
+                (obj1_meta.app_label in self.route_app_labels and obj1_meta.model_name not in self.exclude_models) or
+                (obj2_meta.app_label in self.route_app_labels and obj2_meta.model_name not in self.exclude_models)
         ):
             return True
         return None
